==> echobase-ui-2.1-sources.jar: fr/ifremer/echobase/ui/interceptors/CheckWorkingDbSelected.java <==
package fr.ifremer.echobase.ui.interceptors;

/*
 * #%L
 * EchoBase :: UI
 * $Id: CheckWorkingDbSelected.java 722 2012-10-11 12:20:26Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/echobase/tags/echobase-2.1/echobase-ui/src/main/java/fr/ifremer/echobase/ui/interceptors/CheckWorkingDbSelected.java $
 * %%
 * Copyright (C) 2011 - 2012 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

import com.opensymphony.xwork2.ActionInvocation;
import fr.ifremer.echobase.ui.EchoBaseSession;
import fr.ifremer.echobase.ui.actions.EchoBaseActionSupport;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import static org.nuiton.i18n.I18n.l_;

/**
 * Checks that a working db was selected, otherwise redirect to home.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class CheckWorkingDbSelected extends AbstractCheckInterceptor {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(CheckLogguedInterceptor.class);

    @Override
    protected boolean doCheck(ActionInvocation invocation) {
        EchoBaseActionSupport action = (EchoBaseActionSupport)
                invocation.getAction();

        EchoBaseSession echoBaseSession = action.getEchoBaseSession();
        boolean dbSelected = echoBaseSession.isWorkingDbSelected();
        if (!dbSelected) {
            action.addFlashMessage(l_(action.getLocale(),
                                      "echobase.info.no.workingDb.selected"));
            if (log.isDebugEnabled()) {
                log.debug("No working db selected, will redirect to home");
            }
        }
        return dbSelected;
    }
}

==> echobase-ui-2.2-sources.jar: fr/ifremer/echobase/ui/interceptors/CheckWorkingDbSelected.java <==
package fr.ifremer.echobase.ui.interceptors;

/*
 * #%L
 * EchoBase :: UI
 * $Id: CheckWorkingDbSelected.java 842 2013-08-15 10:53:16Z tchemit $
 * $HeadURL: https://forge.codelutin.com/svn/echobase/tags/echobase-2.2/echobase-ui/src/main/java/fr/ifremer/echobase/ui/interceptors/CheckWorkingDbSelected.java $
 * %%
 * Copyright (C) 2011 - 2012 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

import com.opensymphony.xwork2.ActionInvocation;
import fr.ifremer.echobase.ui.EchoBaseSession;
import fr.ifremer.echobase.ui.actions.EchoBaseActionSupport;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import static org.nuiton.i18n.I18n.l_;

/**
 * Checks that a working db was selected, otherwise redirect to home.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class CheckWorkingDbSelected extends AbstractCheckInterceptor {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(CheckLogguedInterceptor.class);

    @Override
    protected boolean doCheck(ActionInvocation invocation) {
        EchoBaseActionSupport action = (EchoBaseActionSupport)
                invocation.getAction();

        EchoBaseSession echoBaseSession = EchoBaseSession.getEchoBaseSession(
                invocation.getInvocationContext());
        boolean dbSelected = echoBaseSession.isWorkingDbSelected();
        if (!dbSelected) {
            action.addFlashMessage(l_(action.getLocale(),
                                      "echobase.info.no.workingDb.selected"));
            if (log.isDebugEnabled()) {
                log.debug("No working db selected, will redirect to home");
            }
        }
        return dbSelected;
    }
}
